/*======================================================================*\
|*		Editor mined						*|
|*		keyboard mapping tables					*|
\*======================================================================*/

#ifdef vms
#define NOSTRINGTABLES
#define noCJKkeymaps
#endif


#include "mined.h"


#ifdef msdos
#define noCJKkeymaps
#endif


/*======================================================================*\
|*		Keyboard mapping tables					*|
\*======================================================================*/

#ifdef use_keymap_tables

#ifdef keymapping_stringtables
#include "_keymaps.h"
#else
# ifdef noCJKkeymaps
#include "keymapsd.h"
# else
#include "keymapsi.h"
# endif
#endif

#endif


/*======================================================================*\
|*		Table of tables						*|
\*======================================================================*/

struct keymapping keymappingtable [] = {
#ifdef use_keymap_tables
# ifdef noCJKkeymaps
#include "keymapsd.t"
# else
#include "keymapsk.t"
# endif
#else
# ifdef __TURBOC__
	{0, "--"},
# endif
#endif
};

unsigned int keymappingtable_len = arrlen (keymappingtable);


/*======================================================================*\
|*				End					*|
\*======================================================================*/
